Index: src/arm/constants-arm.h |
=================================================================== |
--- src/arm/constants-arm.h (revision 6683) |
+++ src/arm/constants-arm.h (working copy) |
@@ -139,7 +139,9 @@ |
// Aliases. |
hs = cs, // C set Unsigned higher or same. |
- lo = cc // C clear Unsigned lower. |
+ lo = cc, // C clear Unsigned lower. |
+ |
+ kConditionMask = 15 << 28 // Mask for the condition field. |
Alexandre
2011/02/09 13:57:16
kCondMask was already defined (~line 259).
I thin
Søren Thygesen Gjesse
2011/02/09 14:48:28
Removed this again.
|
}; |
@@ -582,6 +584,7 @@ |
inline int TypeValue() const { return Bits(27, 25); } |
inline int RnValue() const { return Bits(19, 16); } |
+ DECLARE_STATIC_ACCESSOR(RnValue); |
inline int RdValue() const { return Bits(15, 12); } |
DECLARE_STATIC_ACCESSOR(RdValue); |
@@ -625,6 +628,7 @@ |
inline int SValue() const { return Bit(20); } |
// with register |
inline int RmValue() const { return Bits(3, 0); } |
+ DECLARE_STATIC_ACCESSOR(RmValue); |
inline int ShiftValue() const { return static_cast<ShiftOp>(Bits(6, 5)); } |
inline ShiftOp ShiftField() const { |
return static_cast<ShiftOp>(BitField(6, 5)); |